diff hgext/mq.py @ 8026:683d8ebcf434

expand "dir" to "directory" in help texts
author Martin Geisler <mg@lazybytes.net>
date Tue, 07 Apr 2009 22:47:56 +0200
parents 3c22fdc741d8
children 9c7ca86fc658
line wrap: on
line diff
--- a/hgext/mq.py	Wed Apr 08 19:32:16 2009 +0200
+++ b/hgext/mq.py	Tue Apr 07 22:47:56 2009 +0200
@@ -2218,7 +2218,7 @@
 def strip(ui, repo, rev, **opts):
     """strip a revision and all its descendants from the repository
 
     If one of the working dir's parent revisions is stripped, the
     working directory will be updated to the parent of the stripped
     revision.
     """
@@ -2514,7 +2514,7 @@
     'qheader': (header, [], _('hg qheader [PATCH]')),
     "^qimport":
         (qimport,
-         [('e', 'existing', None, _('import file in patch dir')),
+         [('e', 'existing', None, _('import file in patch directory')),
           ('n', 'name', '', _('patch file name')),
           ('f', 'force', None, _('overwrite existing files')),
           ('r', 'rev', [], _('place existing revisions under mq control')),
@@ -2567,7 +2567,7 @@
     "qrestore":
         (restore,
          [('d', 'delete', None, _('delete save entry')),
-          ('u', 'update', None, _('update queue working dir'))],
+          ('u', 'update', None, _('update queue working directory'))],
          _('hg qrestore [-d] [-u] REV')),
     "qsave":
         (save,
@@ -2218,7 +2218,7 @@
     """strip a revision and all its descendants from the repository
 
-    If one of the working dir's parent revisions is stripped, the
+    If one of the working directory's parent revisions is stripped, the
     working directory will be updated to the parent of the stripped
     revision.